        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 23 <br>1,3,5,6,9,13,16,18,21,25,26,28,29,31,32,33,35,37,38,41,42,44,46';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 16 <strong>control</strong><br>0,8,10,12,14,15,22,23,24,30,34,39,40,45,47,50';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 12 <br>2,4,7,11,17,19,20,27,36,43,48,49';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 23 <br>1,3,5,6,9,13,16,18,21,25,26,28,29,31,32,33,35,37,38,41,42,44,46';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 16 <strong>control</strong><br>0,8,10,12,14,15,22,23,24,30,34,39,40,45,47,50';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 12 <br>2,4,7,11,17,19,20,27,36,43,48,49';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 23 <br>1,3,5,6,9,13,16,18,21,25,26,28,29,31,32,33,35,37,38,41,42,44,46';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 16 <strong>control</strong><br>0,8,10,12,14,15,22,23,24,30,34,39,40,45,47,50';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 12 <br>2,4,7,11,17,19,20,27,36,43,48,49';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 23 <br>1,3,5,6,9,13,16,18,21,25,26,28,29,31,32,33,35,37,38,41,42,44,46';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 16 <strong>control</strong><br>0,8,10,12,14,15,22,23,24,30,34,39,40,45,47,50';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 12 <br>2,4,7,11,17,19,20,27,36,43,48,49';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 23 <br>1,3,5,6,9,13,16,18,21,25,26,28,29,31,32,33,35,37,38,41,42,44,46';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 16 <strong>control</strong><br>0,8,10,12,14,15,22,23,24,30,34,39,40,45,47,50';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 12 <br>2,4,7,11,17,19,20,27,36,43,48,49';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 23 <br>1,3,5,6,9,13,16,18,21,25,26,28,29,31,32,33,35,37,38,41,42,44,46';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 16 <strong>control</strong><br>0,8,10,12,14,15,22,23,24,30,34,39,40,45,47,50';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 12 <br>2,4,7,11,17,19,20,27,36,43,48,49';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 23 <br>1,3,5,6,9,13,16,18,21,25,26,28,29,31,32,33,35,37,38,41,42,44,46';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 16 <strong>control</strong><br>0,8,10,12,14,15,22,23,24,30,34,39,40,45,47,50';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260426 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 12 <br>2,4,7,11,17,19,20,27,36,43,48,49';}
}
